@@ -1,7 +1,7 @@
 use strict;
 package Crypt::Mode::CBC::Easy;
 #ABSTRACT: Encrypts/decrypts text and verifies decrypted text with a checksum and a random initialization vector.
-$Crypt::Mode::CBC::Easy::VERSION = '0.002';
+$Crypt::Mode::CBC::Easy::VERSION = '0.003';
 use Mouse;
 use Crypt::CBC;
 use Digest::SHA;
@@ -126,7 +126,7 @@ Crypt::Mode::CBC::Easy - Encrypts/decrypts text and verifies decrypted text with
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -150,6 +150,11 @@ version 0.002
         print "plain text: $plain_text\n";
     }
 
+    # or get plain texts as one string separated by separator
+    my $plain_text = $crypt->decrypt($cipher_text);
+
+    print "Plain text: $plain_text\n";
+
 =head1 DESCRIPTION
 
 A convenience class that wraps L<Crypt::Mode::CBC> and adds random initialization vector support along with
@@ -159,7 +164,8 @@ a checksum to make sure that all decrypted text has not been tampered with.
 
 =head2 key
 
-The key that will be used for encrypting and decrypting.
+The key that will be used for encrypting and decrypting. The key should be the appropriate length for the L<Crypt::Cipher> used with
+L</crypt_mode_cbc>. For the default L<Crypt::Cipher> used, Twofish, the key should be 128/192/256 bits.
 
 =head2 crypt_mode_cbc
 
@@ -184,13 +190,13 @@ A L<Bytes::Random::Secure> instance that is used to generate the initialization
 
 =head2 separator
 
-Sets the separator between the encrypted text and its checksum. This should not need to be changed, and is only available for backwards
+Sets the separator between the initialization vector, the encrypted text, and the checksum. This should not need to be changed, and is only available for backwards
 compatability with L<DBIx::Raw> which used to use L<DBIx::Raw::Crypt>. Default value is '::~;~;~::'. If you need to change this for backwards
 compatability, use ':;:'.
 
 =head2 encrypt
 
-Encrypts bytes or an array of bytes.
+Encrypts plain texts or an array of plain texts.
 
     my $cipher_text = $crypt->encrypt($text);
 
@@ -200,7 +206,7 @@ Encrypts bytes or an array of bytes.
 
 =head2 decrypt
 
-Decrypts cipher text into one string or an array of strings.
+Decrypts cipher text into one plain text or an array of plain texts.
 
     my $plain_text = $crypt->encrypt($cipher_text);
 
